@@ -24,5 +24,7 @@ public interface TabResourcesProperties extends PropertyAccess<TabResource> {
 	ValueProvider<TabResource, String> name();
 	ValueProvider<TabResource, String> agency();
 	ValueProvider<TabResource, String> date();
+	ValueProvider<TabResource, String> tabularResourceType();
+	ValueProvider<TabResource, String> ownerLogin();
 
 }
